@@ -14,7 +14,7 @@
 #include "utils/controls.h"
 #include "uiutils.h"
 #include "battle.h"
-#include "iunitsync.h"
+#include "springunitsync.h"
 #include "mmoptionwindows.h"
 #include "utils/conversion.h"
 
@@ -70,7 +70,7 @@ AddBotDialog::AddBotDialog( wxWindow* parent, IBattle& battle , bool singleplaye
 
 	m_main_sizer->Add( m_ai_sizer, 0, wxEXPAND, 5 );
 
-	if ( usync().VersionSupports( IUnitSync::USYNC_GetSkirmishAI ) )
+	if ( usync().VersionSupports( SpringUnitSync::USYNC_GetSkirmishAI ) )
 	{
 		m_ai_infos_lst = new wxListCtrl( this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxSUNKEN_BORDER | wxLC_REPORT | wxLC_SINGLE_SEL | wxLC_NO_HEADER );
 		wxListItem col;
@@ -161,7 +161,7 @@ int AddBotDialog::GetAIType()
 wxString AddBotDialog::RefineAIName( const wxString& name )
 {
   wxString ret = name;
-  if ( !usync().VersionSupports( IUnitSync::USYNC_GetSkirmishAI ) )
+  if ( !usync().VersionSupports( SpringUnitSync::USYNC_GetSkirmishAI ) )
   {
 		if ( ret.Find(_T('.')) != wxNOT_FOUND ) ret = ret.BeforeLast(_T('.'));
 		if ( ret.Find(_T('/')) != wxNOT_FOUND ) ret = ret.AfterLast(_T('/'));
@@ -172,7 +172,7 @@ wxString AddBotDialog::RefineAIName( const wxString& name )
   wxString ret2;
   int i = 2;
   do {
-    ret2 = ret + wxString::Format( _T(" (%d)"), i );
+	ret2 = ret + wxFormat( _T(" (%d)") ) % i;
     i++;
   } while ( m_ai->FindString( ret2 ) != wxNOT_FOUND );
   return ret2;
@@ -230,7 +230,7 @@ void AddBotDialog::OnSelectBot( wxCommandEvent& /*unused*/ )
 void AddBotDialog::ShowAIInfo()
 {
   m_add_btn->Enable( m_ai->GetStringSelection() != wxEmptyString );
-  if ( !usync().VersionSupports( IUnitSync::USYNC_GetSkirmishAI ) ) return;
+  if ( !usync().VersionSupports( SpringUnitSync::USYNC_GetSkirmishAI ) ) return;
   m_ai_infos_lst->DeleteAllItems();
   wxArrayString info = usync().GetAIInfos( GetAIType() );
   int count = info.GetCount();
@@ -249,7 +249,7 @@ void AddBotDialog::ShowAIInfo()
 
 void AddBotDialog::ShowAIOptions()
 {
-  if ( !usync().VersionSupports( IUnitSync::USYNC_GetSkirmishAI ) ) return;
+  if ( !usync().VersionSupports( SpringUnitSync::USYNC_GetSkirmishAI ) ) return;
   m_opts_list->DeleteAllItems();
   m_opt_list_map.clear();
   m_battle.CustomBattleOptions().loadAIOptions( m_battle.GetHostModName(), GetAIType(), GetNick() );
@@ -266,7 +266,7 @@ long AddBotDialog::AddMMOptionsToList( long pos, int optFlag )
 	for ( OptionsWrapper::wxStringTripleVec::const_iterator it = optlist.begin(); it != optlist.end(); ++it )
 	{
 		m_opts_list->InsertItem( pos, it->second.first );
-		wxString tag = wxString::Format( _T( "%d_" ), optFlag ) + it->first;
+		wxString tag = wxFormat( _T( "%d_%s" ) ) % optFlag % it->first;
 		m_opt_list_map[ tag ] = pos;
 		UpdateOption( tag );
 		pos++;
