@@ -4,7 +4,7 @@
 //
 #include "battle.h"
 #include "ui.h"
-#include "iunitsync.h"
+#include "springunitsync.h"
 #include "server.h"
 #include "user.h"
 #include "utils/misc.h"
@@ -185,7 +185,7 @@ void Battle::SaveMapDefaults()
 void Battle::LoadMapDefaults( const wxString& mapname )
 {
 	CustomBattleOptions().setSingleOption( _T("startpostype"), sett().GetMapLastStartPosType( mapname ), OptionsWrapper::EngineOption );
-	SendHostInfo( wxString::Format( _T("%d_startpostype"), OptionsWrapper::EngineOption ) );
+	SendHostInfo( wxFormat( _T("%d_startpostype") ) % OptionsWrapper::EngineOption );
 
 	for( unsigned int i = 0; i <= GetLastRectIdx(); ++i ) if ( GetStartRect( i ).IsOk() ) RemoveStartRect(i); // remove all rects
 	SendHostInfo( IBattle::HI_StartRects );
@@ -1144,7 +1144,7 @@ void Battle::FixTeamIDs( BalanceType balance_type, bool support_clans, bool stro
         for ( size_t j = 0; j < control_teams[i].players.size(); ++j )
         {
             ASSERT_LOGIC( control_teams[i].players[j], _T("fail in Autobalance teams, NULL player") );
-            wxString msg = wxString::Format( _T("setting player %s to team and ally %d"), control_teams[i].players[j]->GetNick().c_str(), i );
+			wxString msg = wxFormat( _T("setting player %s to team and ally %d") ) % control_teams[i].players[j]->GetNick() % i;
             wxLogMessage( _T("%s"), msg.c_str() );
             ForceTeam( *control_teams[i].players[j], control_teams[i].teamnum );
             ForceAlly( *control_teams[i].players[j], control_teams[i].teamnum );
