@@ -15,7 +15,7 @@
 
 #include "battleroomlistctrl.h"
 #include "iconimagelist.h"
-#include "iunitsync.h"
+#include "springunitsync.h"
 #include "battle.h"
 #include "ibattle.h"
 #include "uiutils.h"
@@ -145,7 +145,7 @@ BattleroomListCtrl::BattleroomListCtrl( wxWindow* parent, IBattle* battle, bool
 
 		for ( unsigned int i = 0; i < SPRING_MAX_TEAMS; i++ )
 		{
-			wxMenuItem* team = new wxMenuItem( m_teams, BRLIST_TEAM + i, wxString::Format( _T("%d"), i+1 ) , wxEmptyString, wxITEM_NORMAL );
+			wxMenuItem* team = new wxMenuItem( m_teams, BRLIST_TEAM + i, wxFormat( _T("%d") ) % (i+1), wxEmptyString, wxITEM_NORMAL );
 			m_teams->Append( team );
 			Connect( BRLIST_TEAM + i, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( BattleroomListCtrl::OnTeamSelect ) );
 		}
@@ -154,7 +154,7 @@ BattleroomListCtrl::BattleroomListCtrl( wxWindow* parent, IBattle* battle, bool
 		wxMenu* m_allies = new wxMenu();
 		for ( unsigned int i = 0; i < SPRING_MAX_ALLIES; i++ )
 		{
-			wxMenuItem* ally = new wxMenuItem( m_allies, BRLIST_ALLY + i, wxString::Format( _T("%d"), i+1 ) , wxEmptyString, wxITEM_NORMAL );
+			wxMenuItem* ally = new wxMenuItem( m_allies, BRLIST_ALLY + i, wxFormat( _T("%d") ) % (i+1), wxEmptyString, wxITEM_NORMAL );
 			m_allies->Append( ally );
 			Connect( BRLIST_ALLY + i, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( BattleroomListCtrl::OnAllySelect ) );
 		}
@@ -322,24 +322,24 @@ wxString BattleroomListCtrl::GetItemText(long item, long column) const
 			ASSERT_EXCEPTION( user.BattleStatus().side < (long)sides.GetCount(), _T("Side index too high") );
 		}
 		catch ( ... ) {
-			return wxString::Format( _T("s%d"), user.BattleStatus().side + 1 );
+			return wxFormat( _T("s%d") ) % (user.BattleStatus().side + 1);
 		}
 		return _T("");
 	}
 	if ( column == m_nick_column_index ) return is_bot ? user.GetNick() + _T(" (") + user.BattleStatus().owner + _T(")") : user.GetNick();
-	if ( column == m_team_column_index ) return is_spec ? _T("") : wxString::Format( _T("%d"), user.BattleStatus().team + 1 );
-	if ( column == m_ally_column_index ) return is_spec ? _T("") : wxString::Format( _T("%d"), user.BattleStatus().ally + 1 );
+	if ( column == m_team_column_index ) return is_spec ? _T("") : (wxFormat( _T("%d") ) % ( user.BattleStatus().team + 1 ) ).c_str();
+	if ( column == m_ally_column_index ) return is_spec ? _T("") : (wxFormat( _T("%d") ) % ( user.BattleStatus().ally + 1 ) ).c_str();
 	if ( column == m_cpu_column_index ) {
 		if (!is_bot ) {
 			if ( user.GetCpu() > 0 )
-				return wxString::Format( _T("%.1f GHz"), user.GetCpu() / 1000.0 );
+				return wxFormat( _T("%.1f GHz") ) % ( user.GetCpu() / 1000.0 );
 			else
 				return _T("n/a");//0 cpu in replays for example
 		}
 		else { //!TODO could prolly be cached
 			wxString botname = user.BattleStatus().aishortname;
 			if ( !user.BattleStatus().aiversion.IsEmpty() ) botname += _T(" ") + user.BattleStatus().aiversion;
-			if ( !usync().VersionSupports( IUnitSync::USYNC_GetSkirmishAI ) )
+			if ( !usync().VersionSupports( SpringUnitSync::USYNC_GetSkirmishAI ) )
 			{
 				if ( botname.Find(_T('.')) != wxNOT_FOUND ) botname = botname.BeforeLast(_T('.'));
 				if ( botname.Find(_T('/')) != wxNOT_FOUND ) botname = botname.AfterLast(_T('/'));
@@ -349,7 +349,7 @@ wxString BattleroomListCtrl::GetItemText(long item, long column) const
 			return botname;
 		}
 	}
-	if ( column == m_resourcebonus_column_index ) return is_spec ? _T("") : wxString::Format( _T("%d%%"), user.BattleStatus().handicap );
+	if ( column == m_resourcebonus_column_index ) return is_spec ? _T("") : (wxFormat( _T("%d%%") ) % user.BattleStatus().handicap ).c_str();
 	if ( column == m_country_column_index ) return _T("");
 
 	return _T("");
