@@ -6,7 +6,8 @@
 
 ChannelChooserDialog::ChannelChooserDialog(wxWindow* parent, wxWindowID id,
             const wxString& title, long style )
-    : wxDialog ( parent, id, title, wxDefaultPosition, wxDefaultSize, style )
+	: wxDialog ( parent, id, title, wxDefaultPosition, wxDefaultSize, style ),
+	WindowAttributesPickle( _T("CHANNELCHOOSER"), this, wxSize( 470, 400 ) )
 {
     m_main_sizer = new wxBoxSizer( wxVERTICAL );
 
@@ -14,21 +15,11 @@ ChannelChooserDialog::ChannelChooserDialog(wxWindow* parent, wxWindowID id,
     m_main_sizer->Add( m_chooser_panel, 1, wxALL | wxEXPAND, 5 );
 
     SetSizer( m_main_sizer );
-
-    wxString name = _T("CHANNELCHOOSER");
-    wxPoint pos = sett().GetWindowPos( name, wxDefaultPosition );
-    wxSize size = sett().GetWindowSize( name, wxSize( 470, 400 ) );
-    SetSize( pos.x , pos.y, size.GetWidth(), size.GetHeight() );
     Layout();
 }
 
 ChannelChooserDialog::~ChannelChooserDialog()
-{
-    wxString name = _T("CHANNELCHOOSER");
-    sett().SetWindowSize( name, GetSize() );
-    sett().SetWindowPos( name, GetPosition() );
-    sett().SaveSettings();
-}
+{}
 
 void ChannelChooserDialog::AddChannel( const wxString& name, int usercount, const wxString& topic )
 {
