@@ -1,15 +1,17 @@
-/* Copyright (C) 2007-2009 The SpringLobby Team. All rights reserved. */
+/* Copyright (C) 2007-2011 The SpringLobby Team. All rights reserved. */
 
 #include "customizations.h"
 #include "springunitsynclib.h"
 #include "images/springlobby.xpm"
+#include "images/springlobby_64.png.h"
+#include "uiutils.h"
 
 #include <wx/image.h>
+#include <wx/frame.h>
 #include <wx/msgdlg.h>
 #ifdef SL_QT_MODE
 	#include <QImage>
 	#include <qt/converters.h>
-
 #endif
 const wxString Customizations::IntroKey = wxString ( _T("intro_file") );
 
@@ -22,9 +24,9 @@ const OptionsWrapper& Customizations::GetCustomizations() const
   *
   * @todo: document this function
   */
-const wxIcon& Customizations::GetAppIcon() const
+const wxIconBundle& Customizations::GetAppIconBundle() const
 {
-    return m_app_ico;
+	return m_app_icons;
 }
 
 /** @brief GetHelpUrl
@@ -59,9 +61,18 @@ bool Customizations::Init(const wxString& archive_name )
 		m_shortname = ToQString( shortname );
 #endif
 		wxBitmap icon_bmp( wxNullBitmap );
-		GetBitmap( _T("icon"), icon_bmp );
-
-        m_app_ico.CopyFromBitmap( icon_bmp );
+		if ( GetBitmap( _T("icon"), icon_bmp ) )
+		{
+			wxIcon tmp;
+			tmp.CopyFromBitmap( icon_bmp );
+			m_app_icons = wxIconBundle( tmp );//replacing current
+			int i = 1;
+			while( GetBitmap( wxString::Format(_T("icon%d"), i ), icon_bmp ) )
+			{
+				tmp.CopyFromBitmap( icon_bmp );
+				m_app_icons.AddIcon( tmp );
+			}
+		}
         m_help_url = m_customs.getSingleValue( _T("help_url") );
     }
 	m_active =  ret;
@@ -73,10 +84,10 @@ bool Customizations::Init(const wxString& archive_name )
   * @todo: document this function
   */
  Customizations::Customizations()
-	 : m_app_ico(springlobby_xpm),
+	 : m_app_icons(wxIcon(springlobby_xpm)),
 	 m_active( false )
 {
-
+	m_app_icons.AddIcon( charArr2wxIcon( springlobby_64_png, sizeof(springlobby_64_png) ) );
 }
 
 bool Customizations::GetBitmap( const wxString& key, wxBitmap& bitmap )
