@@ -88,7 +88,7 @@ void NotificationManager::OnTimer( wxTimerEvent& /*event*/ )
 		if ( m_eventDataBuffer.size() == 1 )
 			data = m_eventDataBuffer.front();
 		else
-			data.second = wxString::Format( _("%d more events"), m_eventDataBuffer.size() );
+			data.second = wxFormat( _("%d more events") ) % m_eventDataBuffer.size();
 		m_eventDataBuffer.clear();
 		ShowNotification( data );
 	}
