@@ -29,14 +29,15 @@ IBattle::IBattle():
   m_map_exists(false),
   m_mod_exists(false),
   m_previous_local_mod_name( wxEmptyString ),
-  m_auto_unspec(false),
   m_ingame(false),
+  m_auto_unspec(false),
   m_generating_script(false),
   m_players_ready(0),
   m_players_sync(0),
   m_players_ok(0),
   m_is_self_in(false),
-	m_timer ( 0 )
+	m_timer ( 0 ),
+	m_start_time(0)
 {
 }
 
@@ -867,6 +868,7 @@ std::map<wxString,int> IBattle::RestrictedUnits() const
 
 void IBattle::OnSelfLeftBattle()
 {
+	GetMe().BattleStatus().spectator = false; // always reset back yourself to player when rejoining
 	if ( m_timer ) m_timer->Stop();
 	delete m_timer;
 	m_timer = 0;
@@ -968,7 +970,7 @@ bool IBattle::LoadOptionsPreset( const wxString& name )
       	RestrictUnit( unitinfo.BeforeLast(_T('=')), s2l( unitinfo.AfterLast(_T('=')) ) );
       }
       SendHostInfo( HI_Restrictions );
-      Update( wxString::Format( _T("%d_restrictions"), OptionsWrapper::PrivateOptions ) );
+	  Update( wxFormat( _T("%d_restrictions") ) % OptionsWrapper::PrivateOptions );
 
     }
   }
@@ -1281,3 +1283,17 @@ void IBattle::GetBattleFromScript( bool loadmapmod )
     SetBattleOptions( opts );
 }
 
+void IBattle::SetInGame(bool ingame)
+{
+	m_ingame = ingame;
+	if (m_ingame) m_start_time = wxGetUTCTime();
+	else m_start_time = 0;
+}
+
+long IBattle::GetBattleRunningTime() const
+{
+	if (!GetInGame()) return 0;
+	if (m_start_time == 0 ) return 0;
+	return wxGetUTCTime() - m_start_time;
+}
+
