@@ -78,6 +78,7 @@ class MainWindow : public wxFrame, public WindowAttributesPickle
 	void OnMenuServerTab( wxCommandEvent& event );
     void OnMenuSaveOptions( wxCommandEvent& event );
     void OnMenuQuit( wxCommandEvent& event );
+	void OnMenuPathInfo( wxCommandEvent& event );
     void OnMenuVersion ( wxCommandEvent& event );
     void OnMenuSaveLayout( wxCommandEvent& event );
     void OnMenuLoadLayout( wxCommandEvent& event );
@@ -191,7 +192,8 @@ class MainWindow : public wxFrame, public WindowAttributesPickle
 		MENU_SCREENSHOTS,
 		MENU_PREFERENCES,
 		MENU_RENAME,
-		MENU_GENERAL_HELP
+		MENU_GENERAL_HELP,
+		MENU_PATHINFO
     };
 
         class TabNames : public wxArrayString
@@ -252,13 +254,13 @@ class MainWindow : public wxFrame, public WindowAttributesPickle
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
-    springsettings is distributed in the hope that it will be useful,
+    SpringLobby is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
