@@ -15,12 +15,12 @@ public:
 	hotkey_parser( const wxString& filename );
 	~hotkey_parser();
 
-	const key_binding& getBindingsC2K() const;
-	const key_binding& getBindingsK2C() const;
+	const key_binding& getBindings() const;
 	
 	void writeBindingsToFile( const key_binding& springbindings );
 
-	void dumpIncludeSourceCode( const wxString& filename );
+	bool isDontTouchMode() const;
+	//void dumpIncludeSourceCode( const wxString& filename );
 
 private:
 	//static bool isKeyInProfile( const key_binding& binding, const wxString& command, const wxString& keystring );
@@ -29,10 +29,11 @@ private:
 
 	void updateBindsC2K();
 
-	key_binding		bindsK2C;
-	key_binding		bindsC2K;
+	key_binding			m_bindings;
+	
+	wxString			m_filename;
 
-	wxString		filename;
+	bool				m_dontTouch;
 };
 
-#endif
\ No newline at end of file
+#endif
