@@ -9,7 +9,7 @@ const int CACHE_VERSION     = 11;
 const int SETTINGS_VERSION  = 22;
 
 const wxString DEFSETT_DEFAULT_SERVER_NAME= _T("Official server");
-const wxString DEFSETT_DEFAULT_SERVER_HOST = _T("taspringmaster.clan-sy.com");
+const wxString DEFSETT_DEFAULT_SERVER_HOST = _T("lobby.springrts.com");
 const wxString widgetDownloader_baseUrl = _T("widgetdb.springrts.de");
 const wxString BattlePostfix = _T("_battle");
 const int DEFSETT_DEFAULT_SERVER_PORT = 8200;
@@ -396,22 +396,36 @@ class Settings : public SL::NonCopyable
     void SetSearchSpringOnlyInSLPath( bool value );
     bool GetSearchSpringOnlyInSLPath();
 
+	//!@brief if false, lobby tries to load spring & unitsync as sep paths, otherwise, searches for a bundle containing both
+	bool GetBundleMode();
+	bool IsInsideSpringBundle();
+
+	// enable-disable loading the spring exec from same bundle
+	bool GetUseSpringPathFromBundle();
+	void SetUseSpringPathFromBundle( bool value );
+
     /// convenience wrappers to get current used version paths
 	wxString GetCurrentUsedUikeys();
     wxString GetCurrentUsedDataDir();
     wxString GetCurrentUsedUnitSync();
+    wxString GetCurrentUsedBundle();
     wxString GetCurrentUsedSpringBinary();
     //!@brief returns config file path unitsync uses, returns empty if unitsync isn't loaded
     wxString GetCurrentUsedSpringConfigFilePath();
 
     wxString GetUnitSync( const wxString& index );
     wxString GetSpringBinary( const wxString& index );
+    //!@brief meaningful only on mac
+    wxString GetBundle(const wxString& index );
 
     void SetUnitSync( const wxString& index, const wxString& path );
     void SetSpringBinary( const wxString& index, const wxString& path );
+    //!@brief meaningful only on mac
+    void SetBundle( const wxString& index, const wxString& path );
 
     wxString AutoFindSpringBin();
     wxString AutoFindUnitSync();
+    wxString AutoFindBundle();
 	wxString AutoFindUikeys();
 
     //!@brief returns config file path spring should use, returns empty for default
@@ -782,6 +796,9 @@ class Settings : public SL::NonCopyable
 	bool GetBroadcastEverywhere();
 	void SetBroadcastEverywhere(bool value);
 
+	wxString GlobalConfigPath() const { return m_config ? m_config->GlobalConfigPath() : wxString(); }
+	wxString FinalConfigPath() const { return m_final_config_path; }
+
   protected:
     bool IsSpringBin( const wxString& path );
 
@@ -794,6 +811,8 @@ class Settings : public SL::NonCopyable
     std::map<wxString, wxString> m_spring_versions;
 
 	wxPathList GetConfigFileSearchPathes();
+
+	wxString m_final_config_path;
 };
 
 Settings& sett();
@@ -802,13 +821,13 @@ Settings& sett();
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
-    springsettings is distributed in the hope that it will be useful,
+    SpringLobby is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
