@@ -31,7 +31,7 @@
 
 #include "nonportable.h"
 #include "ui.h"
-#include "iunitsync.h"
+#include "springunitsync.h"
 #include "utils/controls.h"
 #include "utils/platform.h"
 #include "utils/uievents.h"
@@ -45,11 +45,14 @@ BEGIN_EVENT_TABLE( SpringOptionsTab, wxPanel )
 
 	EVT_BUTTON (    SPRING_EXECBROWSE,  SpringOptionsTab::OnBrowseExec  )
 	EVT_BUTTON (    SPRING_SYNCBROWSE,  SpringOptionsTab::OnBrowseSync  )
+	EVT_BUTTON (    SPRING_BUNDLEBROWSE,SpringOptionsTab::OnBrowseBundle)
 	EVT_BUTTON (    SPRING_AUTOCONF,    SpringOptionsTab::OnAutoConf    )
 	EVT_BUTTON (    SPRING_EXECFIND,    SpringOptionsTab::OnFindExec    )
 	EVT_BUTTON (    SPRING_SYNCFIND,    SpringOptionsTab::OnFindSync    )
+	EVT_BUTTON (    SPRING_BUNDLEFIND,  SpringOptionsTab::OnFindBundle  )
 	EVT_BUTTON (    SPRING_DATADIR,     SpringOptionsTab::OnDataDir     )
 	EVT_CHECKBOX(   SPRING_DONTSEARCH,  SpringOptionsTab::OnDontSearch  )
+	EVT_CHECKBOX(   SPRING_FORCEBUNDLE, SpringOptionsTab::OnForceBundle )
 
 END_EVENT_TABLE()
 
@@ -59,12 +62,16 @@ SpringOptionsTab::SpringOptionsTab( wxWindow* parent )
 {
 	m_dontsearch_chkbox = new wxCheckBox( this, SPRING_DONTSEARCH, _("Search only in current installed path"), wxDefaultPosition, wxSize(-1,CONTROL_HEIGHT) );
 	m_dontsearch_chkbox->SetValue( sett().GetSearchSpringOnlyInSLPath() );
-	m_oldlaunch_chkbox = new wxCheckBox( this, SPRING_DONTSEARCH, _("Use old launch method"), wxDefaultPosition, wxSize(-1,CONTROL_HEIGHT) );
+	m_oldlaunch_chkbox = new wxCheckBox( this, SPRING_DONTSEARCH, _("Use alternative launch method (DO NOT TOUCH THIS UNLESS YOU KNOW WHAT YOU'RE DOING)"), wxDefaultPosition, wxSize(-1,CONTROL_HEIGHT) );
 	m_oldlaunch_chkbox->SetValue( sett().UseOldSpringLaunchMethod() );
+	m_forcebundle_chkbox = new wxCheckBox( this, SPRING_FORCEBUNDLE, _("Use the Spring version in the current bundle"), wxDefaultPosition, wxSize(-1,CONTROL_HEIGHT) );
+	m_forcebundle_chkbox->SetValue( sett().GetUseSpringPathFromBundle() );
+	if (!sett().IsInsideSpringBundle()) m_forcebundle_chkbox->Disable();
 #ifndef __WXMSW__
 	m_dontsearch_chkbox->Disable();
 	m_oldlaunch_chkbox->Disable();
 #endif
+	if (!sett().GetBundleMode()) m_forcebundle_chkbox->Disable();
 	/* ================================
 	 * Spring executable
 	 */
@@ -85,6 +92,26 @@ SpringOptionsTab::SpringOptionsTab( wxWindow* parent )
 	m_sync_browse_btn = new wxButton( this, SPRING_SYNCBROWSE, _( "Browse" ) );
 	m_sync_find_btn = new wxButton( this, SPRING_SYNCFIND, _( "Find" ) );
 
+	/* ================================
+	 * Spring Bundle
+	 */
+	m_bundle_box = new wxStaticBox( this, -1, _( "Spring App Bundle" ) );
+
+	m_bundle_edit = new wxTextCtrl( this, -1, sett().GetCurrentUsedBundle() );
+	m_bundle_loc_text = new wxStaticText( this, -1, _( "Location" ) );
+	m_bundle_browse_btn = new wxButton( this, SPRING_BUNDLEBROWSE, _( "Browse" ) );
+	m_bundle_find_btn = new wxButton( this, SPRING_BUNDLEFIND, _( "Find" ) );
+
+	if (sett().GetBundleMode())
+	{
+		EnableSpringBox(false);
+		EnableUnitsyncBox(false);
+	}
+	else
+	{
+		EnableBundleBox(false);
+	}
+
 	m_auto_btn = new wxButton( this, SPRING_AUTOCONF, _( "Auto Configure" ) );
 	m_datadir_btn = new wxButton( this, SPRING_DATADIR, _( "Change Datadir path" ) );
 
@@ -92,6 +119,7 @@ SpringOptionsTab::SpringOptionsTab( wxWindow* parent )
 	m_aconf_sizer = new wxBoxSizer( wxVERTICAL );
 	m_exec_loc_sizer = new wxBoxSizer( wxHORIZONTAL );
 	m_sync_loc_sizer = new wxBoxSizer( wxHORIZONTAL );
+	m_bundle_loc_sizer = new wxBoxSizer( wxHORIZONTAL );
 
 	m_exec_loc_sizer->Add( m_exec_loc_text, 0, wxALL | wxALIGN_CENTER_VERTICAL, 2 );
 	m_exec_loc_sizer->Add( m_exec_edit, 1, wxEXPAND );
@@ -103,20 +131,30 @@ SpringOptionsTab::SpringOptionsTab( wxWindow* parent )
 	m_sync_loc_sizer->Add( m_sync_browse_btn );
 	m_sync_loc_sizer->Add( m_sync_find_btn );
 
+	m_bundle_loc_sizer->Add( m_bundle_loc_text, 0, wxALL | wxALIGN_CENTER_VERTICAL, 2 );
+	m_bundle_loc_sizer->Add( m_bundle_edit, 1, wxEXPAND );
+	m_bundle_loc_sizer->Add( m_bundle_browse_btn );
+	m_bundle_loc_sizer->Add( m_bundle_find_btn );
+
 	m_exec_box_sizer = new wxStaticBoxSizer( m_exec_box, wxVERTICAL );
 	m_sync_box_sizer = new wxStaticBoxSizer( m_sync_box, wxVERTICAL );
+	m_bundle_box_sizer = new wxStaticBoxSizer( m_bundle_box, wxVERTICAL );
 
 	m_exec_box_sizer->Add( m_exec_loc_sizer, 0, wxEXPAND | wxALL, 2 );
 
 	m_sync_box_sizer->Add( m_sync_loc_sizer, 0, wxEXPAND | wxALL, 2 );
 
+	m_bundle_box_sizer->Add( m_bundle_loc_sizer, 0, wxEXPAND | wxALL, 2 );
+
 	m_aconf_sizer->AddStretchSpacer();
 	m_aconf_sizer->Add( m_auto_btn );
 	m_aconf_sizer->Add( m_datadir_btn );
 
 	m_main_sizer->Add( m_dontsearch_chkbox, 0, wxEXPAND | wxALL, 5 );
+	m_main_sizer->Add( m_forcebundle_chkbox, 0, wxEXPAND | wxALL, 5 );
 	m_main_sizer->Add( m_exec_box_sizer, 0, wxEXPAND | wxALL, 5 );
 	m_main_sizer->Add( m_sync_box_sizer, 0, wxEXPAND | wxALL, 5 );
+	m_main_sizer->Add( m_bundle_box_sizer, 0, wxEXPAND | wxALL, 5 );
 	m_main_sizer->Add( m_oldlaunch_chkbox, 0, wxEXPAND | wxALL, 5 );
 	m_main_sizer->Add( m_aconf_sizer, 0, wxEXPAND | wxALL, 5 );
 	m_main_sizer->AddStretchSpacer();
@@ -131,16 +169,23 @@ SpringOptionsTab::SpringOptionsTab( wxWindow* parent )
 
 	if ( sett().IsPortableMode() || sett().GetSearchSpringOnlyInSLPath() )
 	{
-		m_exec_box->Disable();
-		m_sync_box->Disable();
+		EnableSpringBox(false);
+		EnableUnitsyncBox(false);
 		m_auto_btn->Disable();
+		m_bundle_box->Disable();
 		m_datadir_btn->Disable();
 	}
 
+	if ( sett().GetUseSpringPathFromBundle() )
+	{
+		m_bundle_box->Disable();
+	}
+
 	if ( sett().IsFirstRun() )
 	{
 		sett().SetSpringBinary( sett().GetCurrentUsedSpringIndex(), m_exec_edit->GetValue() );
 		sett().SetUnitSync( sett().GetCurrentUsedSpringIndex(), m_sync_edit->GetValue() );
+		sett().SetBundle( sett().GetCurrentUsedSpringIndex(), m_bundle_edit->GetValue() );
 		sett().SetSearchSpringOnlyInSLPath( m_dontsearch_chkbox->IsChecked() );
 	}
 
@@ -152,6 +197,32 @@ SpringOptionsTab::~SpringOptionsTab()
 
 }
 
+void SpringOptionsTab::EnableSpringBox(bool enabled)
+{
+		m_exec_box->Enable(enabled);
+		m_exec_loc_text->Enable(enabled);
+		m_exec_edit->Enable(enabled);
+		m_exec_browse_btn->Enable(enabled);
+		m_exec_find_btn->Enable(enabled);
+}
+
+void SpringOptionsTab::EnableUnitsyncBox(bool enabled)
+{
+		m_sync_box->Enable(enabled);
+		m_sync_loc_text->Enable(enabled);
+		m_sync_edit->Enable(enabled);
+		m_sync_browse_btn->Enable(enabled);
+		m_sync_find_btn->Enable(enabled);
+}
+
+void SpringOptionsTab::EnableBundleBox(bool enabled)
+{
+		m_bundle_box->Enable(enabled);
+		m_bundle_edit->Enable(enabled);
+		m_bundle_loc_text->Enable(enabled);
+		m_bundle_browse_btn->Enable(enabled);
+		m_bundle_find_btn->Enable(enabled);
+}
 
 void SpringOptionsTab::DoRestore()
 {
@@ -159,6 +230,7 @@ void SpringOptionsTab::DoRestore()
     m_oldlaunch_chkbox->SetValue( sett().UseOldSpringLaunchMethod() );
 	m_sync_edit->SetValue( sett().GetCurrentUsedUnitSync() );
 	m_exec_edit->SetValue( sett().GetCurrentUsedSpringBinary() );
+	m_bundle_edit->SetValue( sett().GetCurrentUsedBundle() );
 }
 
 
@@ -166,6 +238,7 @@ void SpringOptionsTab::OnAutoConf( wxCommandEvent& event )
 {
 	OnFindExec( event );
 	OnFindSync( event );
+	OnFindBundle( event );
 }
 
 
@@ -182,6 +255,12 @@ void SpringOptionsTab::OnFindSync( wxCommandEvent& /*unused*/ )
 	if ( !found.IsEmpty() ) m_sync_edit->SetValue( found );
 }
 
+void SpringOptionsTab::OnFindBundle( wxCommandEvent& /*unused*/ )
+{
+	wxString found = sett().AutoFindBundle();
+	if ( !found.IsEmpty() ) m_bundle_edit->SetValue( found );
+}
+
 void SpringOptionsTab::OnBrowseExec( wxCommandEvent& /*unused*/ )
 {
 	wxFileDialog pick( this, _( "Choose a Spring executable" ),
@@ -205,12 +284,22 @@ void SpringOptionsTab::OnBrowseSync( wxCommandEvent& /*unused*/ )
 }
 
 
+void SpringOptionsTab::OnBrowseBundle( wxCommandEvent& /*unused*/ )
+{
+	wxFileDialog pick( this, _( "Choose a Spring executable" ),
+	                   wxPathOnly( sett().GetCurrentUsedBundle() ),
+	                   _T("Spring.App"), wxString(_("App bundle")) + _T("(*.App)||.App") );
+	if ( pick.ShowModal() == wxID_OK ) m_bundle_edit->SetValue( pick.GetPath() );
+}
+
 void SpringOptionsTab::OnApply( wxCommandEvent& /*unused*/ )
 {
 	sett().SetSpringBinary( sett().GetCurrentUsedSpringIndex(), m_exec_edit->GetValue() );
 	sett().SetUnitSync( sett().GetCurrentUsedSpringIndex(), m_sync_edit->GetValue() );
+	sett().SetBundle( sett().GetCurrentUsedSpringIndex(), m_bundle_edit->GetValue() );
 	sett().SetSearchSpringOnlyInSLPath( m_dontsearch_chkbox->IsChecked() );
 	sett().SetOldSpringLaunchMethod( m_oldlaunch_chkbox->IsChecked() );
+	sett().SetUseSpringPathFromBundle( m_forcebundle_chkbox->IsChecked() );
 
 	if ( sett().IsFirstRun() ) return;
 
@@ -239,31 +328,22 @@ void SpringOptionsTab::OnDataDir( wxCommandEvent& /*unused*/ )
 void SpringOptionsTab::OnDontSearch( wxCommandEvent& /*unused*/ )
 {
 	if ( m_dontsearch_chkbox->IsChecked() ) {
-		m_exec_box->Disable();
-		m_sync_box->Disable();
-		m_auto_btn->Disable();
-		m_exec_edit->Disable();
-		m_exec_browse_btn->Disable();
-		m_exec_find_btn->Disable();
-		m_sync_edit->Disable();
-		m_sync_browse_btn->Disable();
-		m_sync_find_btn->Disable();
+		EnableSpringBox(false);
+		EnableUnitsyncBox(false);
 		m_datadir_btn->Disable();
 	}
 	else {
-		m_exec_box->Enable();
-		m_sync_box->Enable();
-		m_auto_btn->Enable();
-		m_exec_edit->Enable();
-		m_exec_browse_btn->Enable();
-		m_exec_find_btn->Enable();
-		m_sync_edit->Enable();
-		m_sync_browse_btn->Enable();
-		m_sync_find_btn->Enable();
+		EnableSpringBox(true);
+		EnableUnitsyncBox(true);
 		m_datadir_btn->Enable();
 	}
 }
 
+void SpringOptionsTab::OnForceBundle( wxCommandEvent& /*unused*/ )
+{
+	EnableBundleBox(!m_forcebundle_chkbox->IsChecked());
+}
+
 /** Try to create the named directory, if it doesn't exist.
  *
  * @param name Path to directory that should exist or be created.
@@ -326,3 +406,4 @@ void SpringOptionsTab::SetupUserFolders()
 		wxCopyFile( uikeyslocation, sett().GetCurrentUsedDataDir() + wxFileName::GetPathSeparator() + _T( "uikeys.txt" ), false );
 	}
 }
+
