@@ -38,9 +38,9 @@
 #define LOCK_UNITSYNC wxCriticalSectionLocker lock_criticalsection(m_lock)
 
 const wxEventType UnitSyncAsyncOperationCompletedEvt = wxNewEventType();
+const wxEventType wxUnitsyncReloadEvent = wxNewEventType();
 
-
-IUnitSync& usync()
+SpringUnitSync& usync()
 {
     static LineInfo<SpringUnitSync> m( AT );
     static GlobalObjectHolder<SpringUnitSync, LineInfo<SpringUnitSync> > m_sync( m );
@@ -55,12 +55,13 @@ SpringUnitSync::SpringUnitSync()
   , m_mapinfo_cache( 1000000, _T("m_mapinfo_cache") )       // this one is just misused as thread safe std::map ...
   , m_sides_cache( 200, _T("m_sides_cache") )               // another misuse
 {
-
+	Connect( wxUnitsyncReloadEvent, wxCommandEventHandler( SpringUnitSync::OnReload ), NULL, this );
 }
 
 
 SpringUnitSync::~SpringUnitSync()
 {
+	Disconnect( wxUnitsyncReloadEvent, wxCommandEventHandler( SpringUnitSync::OnReload ), NULL, this );
 	if ( m_cache_thread )
 	  m_cache_thread->Wait();
 	delete m_cache_thread;
@@ -681,7 +682,7 @@ wxArrayString SpringUnitSync::GetAIList( const wxString& modname ) const
 			{
 				 ret.Add( _T( "LuaAI:" ) +  susynclib().GetLuaAIName( i ) );
 			}
-		} catch (...) {}
+		} CATCH_ANY
 	}
 
   return ret;
@@ -1005,7 +1006,7 @@ wxArrayString SpringUnitSync::GetCacheFile( const wxString& path ) const
   wxArrayString ret;
   wxTextFile file( path );
   file.Open();
-  ASSERT_EXCEPTION( file.IsOpened() , wxString::Format( _T("cache file( %s ) not found"), path.c_str() ) );
+  ASSERT_EXCEPTION( file.IsOpened() , wxFormat( _T("cache file( %s ) not found") ) % path );
   unsigned int linecount = file.GetLineCount();
   for ( unsigned int count = 0; count < linecount; count ++ )
   {
