@@ -6,7 +6,7 @@
 #include <stdexcept>
 
 #include "nonportable.h"
-#include "iunitsync.h"
+#include "springunitsync.h"
 #include "utils/mixins.hh"
 
 class wxString;
@@ -285,7 +285,7 @@ class SpringUnitSyncLib : public SL::NonCopyable
      */
 	wxArrayString GetUnitsyncErrors() const;
 
-	bool VersionSupports( IUnitSync::GameFeature feature ) const;
+	bool VersionSupports( SpringUnitSync::GameFeature feature ) const;
 
 
     int GetModIndex( const wxString& name );
@@ -725,13 +725,13 @@ SpringUnitSyncLib& susynclib();
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
-    springsettings is distributed in the hope that it will be useful,
+    SpringLobby is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
