@@ -1,4 +1,4 @@
-/* Copyright (C) 2007-2009 The SpringLobby Team. All rights reserved. */
+/* Copyright (C) 2007-2011 The SpringLobby Team. All rights reserved. */
 
 
 #ifdef _MSC_VER
@@ -26,7 +26,7 @@
 #include "base64.h"
 #include "utils/md5.h"
 #include "tasserver.h"
-#include "iunitsync.h"
+#include "springunitsync.h"
 #include "user.h"
 #include "utils/debug.h"
 #include "utils/tasutil.h"
@@ -726,10 +726,9 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
 					wxString wxversion = wxVERSION_STRING;
 					wxversion.Replace( _T(" "), _T("") );
 					wxString reportstring = _T("stats.report ") + version + _T(" ") + wxversion + _T(" ") + os + aux;
-					if ( UserExists( _T("insanebot") ) ) SayPrivate( _T("insanebot"), reportstring );
 					if ( UserExists( _T("SL_bot") ) ) SayPrivate( _T("SL_bot"), reportstring );
 				}
-				if ( UserExists( _T("RelayHostManagerList") ) ) SayPrivate( _T("RelayHostManagerList"), _T("!listmanagers") );
+				if ( UserExists( _T("RelayHostManagerList") ) ) SayPrivate( _T("RelayHostManagerList"), _T("!lm") );
         m_se->OnLoginInfoComplete();
     }
     else if ( cmd == _T("REMOVEUSER") )
@@ -810,8 +809,8 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
     {
         nick = GetWordParam( params );
         if ( ( ( nick == m_relay_host_bot ) || ( nick == m_relay_host_manager ) ) && params.StartsWith( _T("!") ) ) return; // drop the message
-        if ( ( nick == _T("RelayHostManagerList") ) && ( params == _T("!listmanagers") ) ) return;// drop the message
-        if ( nick == _T("SL_bot") || ( nick == _T("insanebot") ) )
+        if ( ( nick == _T("RelayHostManagerList") ) && ( params == _T("!lm") ) ) return;// drop the message
+        if ( nick == _T("SL_bot") )
         {
         	if ( params.StartsWith( _T("stats.report") ) ) return;
         }
@@ -862,7 +861,7 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
         }
         if ( nick == _T("RelayHostManagerList") )
 				{
-					if  ( params.StartsWith(_T("managerlist ")) )
+					if  ( params.StartsWith(_T("list ")) )
 					{
 						 wxString list = params.AfterFirst( _T(' ') );
 						 m_relay_host_manager_list = wxStringTokenize( list, _T("\t") );
@@ -989,7 +988,7 @@ void TASServer::ExecuteCommand( const wxString& cmd, const wxString& inparams, i
             wxLogWarning( wxString::Format( _T("Recieved illegal ADDBOT (empty dll field) from %s for battle %d"), nick.c_str(), id ) );
             ai = _T("INVALID|INVALID");
         }
-        if( usync().VersionSupports( IUnitSync::USYNC_GetSkirmishAI ) )
+        if( usync().VersionSupports( SpringUnitSync::USYNC_GetSkirmishAI ) )
         {
 			if (ai.Find(_T('|')) != -1)
 			{
@@ -2187,7 +2186,7 @@ void TASServer::AddBot( int battleid, const wxString& nick, UserBattleStatus& st
     wxString msg;
     wxString ailib;
     ailib += status.aishortname;
-    if ( usync().VersionSupports( IUnitSync::USYNC_GetSkirmishAI ) ) ailib += _T("|") + status.aiversion;
+    if ( usync().VersionSupports( SpringUnitSync::USYNC_GetSkirmishAI ) ) ailib += _T("|") + status.aiversion;
     SendCmd( _T("ADDBOT"), nick + wxString::Format( _T(" %d %d "), tasbs.data, tascl.data ) + ailib );
 }
 
@@ -2249,7 +2248,13 @@ void TASServer::UpdateBot( int battleid, User& bot, UserBattleStatus& status )
 
 void TASServer::SendScriptToProxy( const wxString& script )
 {
-  int time = script.Len() / m_sock->GetSendRateLimit(); // calculate time in seconds to upload script
+  wxArrayString strings = wxStringTokenize( script, _T("\n") );
+  int relaylenghtprefix = 10 + 1 + m_relay_host_bot.Len() + 2; // SAYPRIVATE + space + botname + space + exclamation mark lenght
+  int lenght = script.size();
+  lenght += relaylenghtprefix + 11 + 1; // CLEANSCRIPT command size
+  lenght += strings.GetCount() * ( relaylenghtprefix + 16 + 1 ); // num lines * APPENDSCRIPTLINE + space command size ( \n is already counted in script.size)
+  lenght += relaylenghtprefix + 9 + 1; // STARTGAME command size
+  int time = lenght / m_sock->GetSendRateLimit(); // calculate time in seconds to upload script
   DoActionBattle( m_battle_id, wxString::Format(_T("is preparing to start the game, game will start in approximately %d seconds"),time));
   RelayCmd( _T("CLEANSCRIPT") );
   wxStringTokenizer tkzr( script, _T("\n") );
@@ -2485,7 +2490,7 @@ void TASServer::RequestSpringUpdate()
 
 wxArrayString TASServer::GetRelayHostList()
 {
-	if ( UserExists( _T("RelayHostManagerList") ) ) SayPrivate( _T("RelayHostManagerList"), _T("!listmanagers") );
+	if ( UserExists( _T("RelayHostManagerList") ) ) SayPrivate( _T("RelayHostManagerList"), _T("!lm") );
 	wxArrayString ret;
 	for ( unsigned int i = 0; i < m_relay_host_manager_list.GetCount(); i++ )
 	{
