@@ -60,7 +60,7 @@
 #include "utils/downloader.h"
 #include "utils/uievents.h"
 #include "globalsmanager.h"
-#include "iunitsync.h"
+#include "springunitsync.h"
 #include "utils/globalevents.h"
 
 #ifdef __WXMSW__
@@ -68,19 +68,19 @@
 #endif
 
 /** Get the name of the Spring data subdirectory that corresponds to a
- * given IUnitSync::MediaType value.
+ * given SpringUnitSync::MediaType value.
  */
 inline wxString
-getDataSubdirForType(const IUnitSync::MediaType type)
+getDataSubdirForType(const SpringUnitSync::MediaType type)
 {
     switch ( type)
     {
-    case IUnitSync::map:
+    case SpringUnitSync::map:
         return _T("maps");
-    case IUnitSync::mod:
+    case SpringUnitSync::mod:
 		return _T("games");
     default:
-        ASSERT_EXCEPTION(false, _T("Unhandled IUnitSync::MediaType value"));
+        ASSERT_EXCEPTION(false, _T("Unhandled SpringUnitSync::MediaType value"));
     }
 }
 
@@ -358,10 +358,10 @@ int TorrentWrapper::GetTorrentSystemStatus() const
 ////               lobby interface                  ////
 ////////////////////////////////////////////////////////
 
-IUnitSync::MediaType convertMediaType( const PlasmaResourceInfo::ResourceType& t ) {
+SpringUnitSync::MediaType convertMediaType( const PlasmaResourceInfo::ResourceType& t ) {
     switch ( t ) {
-        case PlasmaResourceInfo::map: return IUnitSync::map;
-        default: return IUnitSync::mod;
+        case PlasmaResourceInfo::map: return SpringUnitSync::map;
+        default: return SpringUnitSync::mod;
     }
 
 }
@@ -490,7 +490,7 @@ void TorrentWrapper::HandleCompleted()
 		libtorrent::torrent_handle handle = it->second;
 		if ( handle.is_valid() && handle.is_seed() )
 		{
-			wxString dest_filename = sett().GetCurrentUsedDataDir() +
+			wxString dest_filename = sett().GetCurrentUsedDataDir() + wxFileName::GetPathSeparator() +
 									 getDataSubdirForType( convertMediaType( info.m_type ) ) +
 									 wxFileName::GetPathSeparator() +
 									 TowxString( handle.get_torrent_info().file_at( 0 ).path.string() );
@@ -505,8 +505,9 @@ void TorrentWrapper::HandleCompleted()
 				bool ok = wxCopyFile( source_path, dest_filename );
 				if ( !ok )
 				{
-					wxString msg = wxString::Format( _("File copy from %s to %s failed.\nPlease copy manually and reload maps/games afterwards"),
-								source_path.c_str(), dest_filename.c_str() );
+					wxString msg = wxFormat( _("File copy from %s to %s failed.\nPlease copy manually and reload maps/mods afterwards") )
+												% source_path
+												% dest_filename;
 					wxLogError( _T("DL: File copy from %s to %s failed."), source_path.c_str(), dest_filename.c_str() );
 					wxMutexGuiLocker locker;
 					#ifdef __WXMSW__
@@ -523,7 +524,7 @@ void TorrentWrapper::HandleCompleted()
 					wxRemoveFile( source_path );
 					wxLogDebug( _T("DL complete: %s"), info.m_name.c_str() );
 					wxMutexGuiLocker locker;
-					UiEvents::StatusData data( wxString::Format( _("Download completed: %s"), info.m_name.c_str() ), 1 );
+					UiEvents::StatusData data( wxFormat( _("Download completed: %s") ) % info.m_name, 1 );
 					UiEvents::GetStatusEventSender( UiEvents::addStatusMessage ).SendEvent( data );
 					num_completed++;
 				}
@@ -653,10 +654,10 @@ void DisplayError( const wxString& resourcename, TorrentWrapper::DownloadRequest
 		case TorrentWrapper::torrent_join_failed: msg = _("The downloaded .torrent file was unusable."); break;
 		default: msg = _("Unknown"); break;
 	}
-	msg = wxString::Format(_("Downloading %s failed with reason:\n%s"), resourcename.c_str(), msg.c_str() );
+	msg = wxFormat(_("Downloading %s failed with reason:\n%s") ) % resourcename % msg;
 	wxString title = _("Download failure");
 #ifdef __WXMSW__
-	UiEvents::StatusData data( wxString::Format(_("Downloading %s failed"), resourcename.c_str() ), 1 );
+	UiEvents::StatusData data( wxFormat(_("Downloading %s failed") ) % resourcename, 1 );
 	UiEvents::GetStatusEventSender( UiEvents::addStatusMessage ).SendEvent( data );
 #else
 	wxMutexGuiLocker locker;
