@@ -3,6 +3,7 @@
 
 #ifndef NO_TORRENT_SYSTEM
 
+#define BOOST_FILESYSTEM_VERSION 2
 
 #include <wx/arrstr.h>
 #include <wx/event.h>
@@ -13,7 +14,7 @@
 
 #include <boost/cstdint.hpp>
 
-#include "iunitsync.h"
+#include "springunitsync.h"
 #include "thread.h"
 #include "mutexwrapper.h"
 #include "utils/plasmaresourceinfo.h"
@@ -164,13 +165,13 @@ TorrentWrapper& torrent();
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
-    springsettings is distributed in the hope that it will be useful,
+    SpringLobby is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
