@@ -9,6 +9,7 @@
 
 class wxColour;
 class wxImage;
+class wxIcon;
 class wxBitmap;
 
 wxString RTFtoText( const wxString& rtfinput );
@@ -31,6 +32,8 @@ wxImage charArr2wxImage(const unsigned char * arg, int size);
 wxBitmap charArr2wxBitmap(const unsigned char * arg, int size);
 wxBitmap charArr2wxBitmapWithBlending(const unsigned char * arg, int size,
             const unsigned char * text, int text_size);
+//! png array data to Icon
+wxIcon charArr2wxIcon(const unsigned char * arg, int size);
 
 wxBitmap getColourIcon( const wxColour& colour );
 
@@ -66,13 +69,13 @@ struct TimerMessageBox: public SL::NonCopyable {
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
-    springsettings is distributed in the hope that it will be useful,
+    SpringLobby is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
