@@ -91,11 +91,34 @@ class BattleSyncReloadSink : public CRTPbase<Derived> {
 			: m_BattleSyncReloadSink( this, &GetGlobalEventSender( GlobalEvents::BattleSyncReload) )
 		{}
 };
+
+template <class Derived >
+class OnLoginSink : public CRTPbase<Derived> {
+	protected:
+		typedef GlobalEvents::GlobalEventData
+			EventDataType;
+		typedef OnLoginSink<Derived>
+			BaseType;
+		using CRTPbase<Derived>::asImp;
+
+	public:
+		void OnLogin( EventDataType data ) { asImp().OnLogin( data ); }
+
+	protected:
+		typedef EventReceiverFunc<OnLoginSink, EventDataType, &OnLoginSink::OnLogin>
+			EventReceiverFunction;
+		EventReceiverFunction m_OnLoginSink;
+
+	public:
+		OnLoginSink()
+			: m_OnLoginSink( this, &GetGlobalEventSender( GlobalEvents::OnLogin) )
+		{}
+};
 #endif // SPRINGLOBBY_HEADERGUARD_ISINK_H
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-2010
+    Copyright (C) 2007-2011
 
     SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
