@@ -7,7 +7,8 @@
 
 WidgetDownloadDialog::WidgetDownloadDialog(wxWindow* parent, wxWindowID id,
             const wxString& title, long style )
-    : wxDialog ( parent, id, title, wxDefaultPosition, wxDefaultSize, style, _T("WIDGETDIALOG") )
+	: wxDialog ( parent, id, title, wxDefaultPosition, wxDefaultSize, style, _T("WIDGETDIALOG") ),
+	WindowAttributesPickle( _T("WIDGETDIALOG"), this, wxSize( 670, 400 ) )
 {
     m_main_sizer = new wxBoxSizer( wxVERTICAL );
 
@@ -15,11 +16,6 @@ WidgetDownloadDialog::WidgetDownloadDialog(wxWindow* parent, wxWindowID id,
     m_main_sizer->Add( m_widgets_panel, 1, wxALL | wxEXPAND, 5 );
 
     SetSizer( m_main_sizer );
-
-    wxString name = GetName();
-    wxPoint pos = sett().GetWindowPos( name, wxDefaultPosition );
-    wxSize size = sett().GetWindowSize( name, wxSize( 670, 400 ) );
-    SetSize( pos.x , pos.y, size.GetWidth(), size.GetHeight() );
     Layout();
 }
 
@@ -30,9 +26,5 @@ WidgetDownloadDialog::~WidgetDownloadDialog()
 
 bool WidgetDownloadDialog::Show( bool show )
 {
-    if ( !show ) {
-        sett().SetWindowSize( GetName(), GetSize() );
-        sett().SetWindowPos( GetName(), GetPosition() );
-    }
     return wxDialog::Show( show );
 }
